﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Mvc.Ajax;
using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using Syncfusion.Mvc.DocIO.Web;
using System.Drawing;
using System.IO;

namespace GenerateWord.Controllers
{
    public class HomeController : Controller
    {
        string dataPath;
        #region Generate Word
        public ActionResult Index(string Group1)
        {
            if (Group1 == null)
                return View();

            dataPath = ResolveApplicationDataPath("\\", "Data");
            //A new document is created.
            WordDocument document = new WordDocument();
            //Adding a new section to the document.
            WSection section = document.AddSection() as WSection;
            //Set Margin of the section
            section.PageSetup.Margins.All = 72;
            //Set page size of the section
            section.PageSetup.PageSize = new SizeF(612, 792);

            //Create Paragraph styles
            WParagraphStyle style = document.AddParagraphStyle("Normal") as WParagraphStyle;
            style.CharacterFormat.FontName = "Calibri";
            style.CharacterFormat.FontSize = 11f;
            style.ParagraphFormat.BeforeSpacing = 0;
            style.ParagraphFormat.AfterSpacing = 8;
            style.ParagraphFormat.LineSpacing = 13.8f;

            style = document.AddParagraphStyle("Heading 1") as WParagraphStyle;
            style.ApplyBaseStyle("Normal");
            style.CharacterFormat.FontName = "Calibri Light";
            style.CharacterFormat.FontSize = 16f;
            style.CharacterFormat.TextColor = Color.FromArgb(46, 116, 181);
            style.ParagraphFormat.BeforeSpacing = 12;
            style.ParagraphFormat.AfterSpacing = 0;
            style.ParagraphFormat.Keep = true;
            style.ParagraphFormat.KeepFollow = true;
            style.ParagraphFormat.OutlineLevel = OutlineLevel.Level1;

            //Appends paragraph.
            IWParagraph paragraph = section.AddParagraph();
            paragraph.ParagraphFormat.AfterSpacing = 0;
            paragraph.BreakCharacterFormat.FontSize = 12f;
            paragraph.ParagraphFormat.HorizontalAlignment = HorizontalAlignment.Right;
            //Appends picture to the paragraph.
            WPicture picture = paragraph.AppendPicture(Image.FromFile(System.IO.Path.Combine(dataPath, "syncfusion_logo.png"))) as WPicture;
            picture.TextWrappingStyle = TextWrappingStyle.TopAndBottom;
            picture.VerticalOrigin = VerticalOrigin.Paragraph;
            picture.VerticalPosition = 0;
            picture.HorizontalOrigin = HorizontalOrigin.Column;
            picture.HorizontalPosition = -5.15f;
            picture.WidthScale = 79;
            picture.HeightScale = 79;

            //Appends paragraph.
            paragraph = section.AddParagraph();
            paragraph.ApplyStyle("Heading 1");
            paragraph.ParagraphFormat.HorizontalAlignment = Syncfusion.DocIO.DLS.HorizontalAlignment.Center;
            WTextRange textRange = paragraph.AppendText("Hello World") as WTextRange;
            textRange.CharacterFormat.FontSize = 18f;
            textRange.CharacterFormat.FontName = "Calibri";

            //Appends table
            WTable table = new WTable(document);
            table.ResetCells(3, 3);
            foreach (WTableRow tableRow in table.Rows)
            {
                foreach (WTableCell tableCell in tableRow.Cells)
                    tableCell.Width = 100;
            }
            table.Rows[0].Cells[0].AddParagraph().AppendText("Cell text");
            table.Rows[0].Cells[1].AddParagraph().AppendText("Cell text");
            table.Rows[0].Cells[2].AddParagraph().AppendText("Cell text");
            table.Rows[1].Cells[0].AddParagraph().AppendText("Cell text");
            table.Rows[1].Cells[1].AddParagraph().AppendText("Cell text");
            table.Rows[1].Cells[2].AddParagraph().AppendText("Cell text");
            document.LastSection.Tables.Add(table);

            //Appends an empty paragraph
            document.LastSection.AddParagraph();

            //Appends another table
            table = new WTable(document);
            table.ResetCells(3, 3);
            table.Rows[0].Cells[0].CellFormat.BackColor = Color.Black;
            table.Rows[0].Cells[1].CellFormat.BackColor = Color.Black;
            table.Rows[0].Cells[2].CellFormat.BackColor = Color.Black;
            foreach (WTableRow row in table.Rows)
            {
                foreach (WTableCell cell in row.Cells)
                    cell.Width = 140;
            }
            table.Rows[1].Cells[0].AddParagraph().AppendText("Cell text");
            table.Rows[1].Cells[1].AddParagraph().AppendText("Cell text");
            table.Rows[1].Cells[2].AddParagraph().AppendText("Cell text");           
            table.Rows[2].Cells[0].AddParagraph().AppendText("Cell text");
            table.Rows[2].Cells[1].AddParagraph().AppendText("Cell text");
            table.Rows[2].Cells[2].AddParagraph().AppendText("Cell text");
            document.LastSection.Tables.Add(table);

            #region Word larger table
            float maxWidth = 0;
            WTable maxTable = null;
            float cellWidth = 0;
            //Iterate and find the table with the maximum cell width
            foreach(WTable wordTable in document.LastSection.Tables)
            {
                foreach(WTableRow row in wordTable.Rows)
                {
                    foreach (WTableCell cell in row.Cells)
                        cellWidth += cell.Width;
                    if (cellWidth > maxWidth)
                    {
                        maxWidth = cellWidth;
                        maxTable = wordTable;
                        cellWidth = 0;
                    }
                }
            }
            //To highlight the table with maximum width
            maxTable.TableFormat.Borders.Color = Color.Blue;
            maxTable.TableFormat.Borders.LineWidth = 3;
            #endregion

            #region saveOption
            if (Group1 == "Word97To2003")
            {
                //Save as .doc Word 97-2003 format
                return document.ExportAsActionResult("Sample.doc", FormatType.Doc, HttpContext.ApplicationInstance.Response, HttpContentDisposition.Attachment);
            }
            //Save as .docx Word 2007 format
            else if (Group1 == "Word2007")
            {
                return document.ExportAsActionResult("Sample.docx", FormatType.Word2007, HttpContext.ApplicationInstance.Response, HttpContentDisposition.Attachment);

            }
            //Save as .docx Word 2010 format
            else if (Group1 == "Word2010")
            {
                return document.ExportAsActionResult("Sample.docx", FormatType.Word2010, HttpContext.ApplicationInstance.Response, HttpContentDisposition.Attachment);

            }
            //Save as .docx Word 2013 format
            else if (Group1 == "Word2013")
            {
                return document.ExportAsActionResult("Sample.docx", FormatType.Word2013, HttpContext.ApplicationInstance.Response, HttpContentDisposition.Attachment);

            }
            #endregion saveOption

            return View();
        }
        #endregion Getting Started
        /// <summary>
        /// Data folder path is resolved from requested page physical path
        /// </summary>
        /// <param name="fileName"></param>
        /// <param name="folderName"></param>
        /// <returns></returns>
        protected string ResolveApplicationDataPath(string fileName, string folderName)
        {
            string dataPath = null;
            dataPath = Server.MapPath(@"App_Data//Images//").ToString();
            return string.Format("{0}\\{1}", dataPath, fileName);
        }
    }
}
